#!/bin/bash

codesign=/usr/bin/codesign

set -x 
set -e

helper=Ubuntu\ One.app/Contents/Library/LaunchServices/com.ubuntu.one.fsevents

echo "\nDisplaying Contents:"
$codesign -d -vvvv Ubuntu\ One.app

echo "\nVerifying Main App:"
$codesign -v -v Ubuntu\ One.app

echo "\nVerifying Daemon:"
$codesign -v -v $helper

echo "\nDouble-check: the SMPrivilegedExecutables entry should show the right ID and CN"
defaults read "`pwd`/Ubuntu\ One.app/Contents/Info.plist" SMPrivilegedExecutables 
defaults read "`pwd`/Ubuntu\ One.app/Contents/Info.plist" SMPrivilegedExecutables | perl -nle 'print "identifier $1 and certificate leaf[subject.CN] = \"$3\"" if /\"(.*)\" = \"identifier (.*) and certificate leaf\[subject.CN\] = \\\\\"(.*)\\\\\"/;' > tmp.req

echo "\nChecking that the helper satisfies the app SMPrivilegedExecutables requirement"
$codesign -v -v -R tmp.req $helper
rm tmp.req

echo "\nChecking that the app satisfies the helper's SMAuthorizedClients requirement"
otool -s __TEXT __info_plist $helper | grep "^[0-9a-f]\{8,16\}" | xxd -r - - > tmp.plist
perl -nle 'print "identifier $1 and certificate leaf[subject.CN] = \"$2\"" if /identifier (.*) and certificate leaf\[subject.CN\] = &quot;(.*)&quot;/;' tmp.plist > tmp.req 
$codesign -v -v -R tmp.req Ubuntu\ One.app
rm tmp.plist tmp.req

echo Done.
